!!! note

    The (open) AEA framework provides the necessary tools for creating 
    Autonomous Economic Agents (AEA). It is a fork of the 
    <a href="https://github.com/fetchai/agents-aea" target="_blank">legacy AEA 
    framework</a> that gives no priority to any package vendor.

The latest version of the Python implementation of the
<a href="https://pypi.org/project/open-aea/" target="_blank">AEA Framework</a>
on PyPI.

If you are upgrading your AEA project from a previous version of the AEA framework, please check out <a href="../upgrading/">the upgrading guide</a>.

The AEA framework's implementation in Python is in principle compatible with its implementation in any other language. The <a href="../language-agnostic-definition/">language agnostic definitions</a> describe the aspects of the framework an implementation must adhere to in order for their AEAs to be able to interact with AEAs built with other implementations of the framework.
